@@ -52,15 +52,30 @@ from .models import (SimplifiedObjectInfo,
                      NoncurrentVersionExpiration,
                      AsyncFetchTaskConfiguration,
                      InventoryConfiguration,
-                     InventoryFilter, 
-                     InventorySchedule, 
-                     InventoryDestination, 
-                     InventoryBucketDestination, 
+                     InventoryFilter,
+                     InventorySchedule,
+                     InventoryDestination,
+                     InventoryBucketDestination,
                      InventoryServerSideEncryptionKMS,
                      InventoryServerSideEncryptionOSS,
                      LocationTransferType,
                      BucketReplicationProgress,
-                     ReplicationRule)
+                     ReplicationRule,
+                     CnameInfo,
+                     CertificateInfo,
+                     ReplicationRule,
+                     MetaQueryFile,
+                     AggregationsInfo,
+                     OSSTaggingInfo,
+                     OSSUserMetaInfo,
+                     AggregationGroupInfo,
+                     AccessMonitorInfo,
+                     LifecycleFilter,
+                     FilterNot,
+                     FilterNotTag,
+                     BucketStyleInfo,
+                     RegionInfo,
+                     CallbackPolicyInfo)
 
 from .select_params import (SelectJsonTypes, SelectParameters)
 
@@ -159,7 +174,8 @@ def parse_list_objects(result, body):
             _find_tag(contents_node, 'Type'),
             int(_find_tag(contents_node, 'Size')),
             _find_tag(contents_node, 'StorageClass'),
-            owner
+            owner,
+            _find_tag_with_default(contents_node, 'RestoreInfo', None)
         ))
 
     for prefix_node in root.findall('CommonPrefixes'):
@@ -186,7 +202,8 @@ def parse_list_objects_v2(result, body):
             _find_tag(contents_node, 'Type'),
             int(_find_tag(contents_node, 'Size')),
             _find_tag(contents_node, 'StorageClass'),
-            owner
+            owner,
+            _find_tag_with_default(contents_node, 'RestoreInfo', None)
         ))
 
     for prefix_node in root.findall('CommonPrefixes'):
@@ -206,6 +223,9 @@ def parse_list_buckets(result, body):
     if result.is_truncated:
         result.next_marker = _find_tag(root, 'NextMarker')
 
+    if root.find('Owner') is not None:
+        result.owner = Owner(_find_tag_with_default(root, 'Owner/DisplayName', None), _find_tag_with_default(root, 'Owner/ID', None))
+
     for bucket_node in root.findall('Buckets/Bucket'):
         result.buckets.append(SimplifiedBucketInfo(
             _find_tag(bucket_node, 'Name'),
@@ -213,7 +233,9 @@ def parse_list_buckets(result, body):
             iso8601_to_unixtime(_find_tag(bucket_node, 'CreationDate')),
             _find_tag(bucket_node, 'ExtranetEndpoint'),
             _find_tag(bucket_node, 'IntranetEndpoint'),
-            _find_tag(bucket_node, 'StorageClass')
+            _find_tag(bucket_node, 'StorageClass'),
+            _find_tag_with_default(bucket_node, 'Region', None),
+            _find_tag_with_default(bucket_node, 'ResourceGroupId', None),
         ))
 
     return result
@@ -330,7 +352,37 @@ def parse_get_bucket_stat(result, body):
 
     result.storage_size_in_bytes = _find_int(root, 'Storage')
     result.object_count = _find_int(root, 'ObjectCount')
-    result.multi_part_upload_count = _find_int(root, 'MultipartUploadCount')
+    result.multi_part_upload_count = int(_find_tag_with_default(root, 'MultipartUploadCount', 0))
+    if root.find('LiveChannelCount') is not None:
+        result.live_channel_count = int(_find_tag(root, 'LiveChannelCount'))
+    if root.find('LastModifiedTime') is not None:
+        result.last_modified_time = int(_find_tag(root, 'LastModifiedTime'))
+    if root.find('StandardStorage') is not None:
+        result.standard_storage = int(_find_tag(root, 'StandardStorage'))
+    if root.find('StandardObjectCount') is not None:
+        result.standard_object_count = int(_find_tag(root, 'StandardObjectCount'))
+    if root.find('InfrequentAccessStorage') is not None:
+        result.infrequent_access_storage = int(_find_tag(root, 'InfrequentAccessStorage'))
+    if root.find('InfrequentAccessRealStorage') is not None:
+        result.infrequent_access_real_storage = int(_find_tag(root, 'InfrequentAccessRealStorage'))
+    if root.find('InfrequentAccessObjectCount') is not None:
+        result.infrequent_access_object_count = int(_find_tag(root, 'InfrequentAccessObjectCount'))
+    if root.find('ArchiveStorage') is not None:
+        result.archive_storage = int(_find_tag(root, 'ArchiveStorage'))
+    if root.find('ArchiveRealStorage') is not None:
+        result.archive_real_storage = int(_find_tag(root, 'ArchiveRealStorage'))
+    if root.find('ArchiveObjectCount') is not None:
+        result.archive_object_count = int(_find_tag(root, 'ArchiveObjectCount'))
+    if root.find('ColdArchiveStorage') is not None:
+        result.cold_archive_storage = int(_find_tag(root, 'ColdArchiveStorage'))
+    if root.find('ColdArchiveRealStorage') is not None:
+        result.cold_archive_real_storage = int(_find_tag(root, 'ColdArchiveRealStorage'))
+    if root.find('ColdArchiveObjectCount') is not None:
+        result.cold_archive_object_count = int(_find_tag(root, 'ColdArchiveObjectCount'))
+    if root.find('MultipartPartCount') is not None:
+        result.multipart_part_count = int(_find_tag(root, 'MultipartPartCount'))
+    if root.find('DeleteMarkerCount') is not None:
+        result.delete_marker_count = int(_find_tag(root, 'DeleteMarkerCount'))
 
     return result
 
@@ -349,6 +401,10 @@ def parse_get_bucket_info(result, body):
     result.comment = _find_tag_with_default(root, 'Bucket/Comment', None)
     result.versioning_status = _find_tag_with_default(root, 'Bucket/Versioning', None)
     result.data_redundancy_type = _find_tag_with_default(root, 'Bucket/DataRedundancyType', None)
+    result.access_monitor = _find_tag_with_default(root, 'Bucket/AccessMonitor', None)
+    result.transfer_acceleration = _find_tag_with_default(root, 'Bucket/TransferAcceleration', None)
+    result.cross_region_replication = _find_tag_with_default(root, 'Bucket/CrossRegionReplication', None)
+    result.resource_group_id = _find_tag_with_default(root, 'Bucket/ResourceGroupId', None)
 
     server_side_encryption = root.find("Bucket/ServerSideEncryptionRule")
     if server_side_encryption is None:
@@ -389,6 +445,11 @@ def parse_get_bucket_referer(result, body):
     result.allow_empty_referer = _find_bool(root, 'AllowEmptyReferer')
     result.referers = _find_all_tags(root, 'RefererList/Referer')
 
+    if root.find("AllowTruncateQueryString") is not None:
+        result.allow_truncate_query_string = _find_bool(root, 'AllowTruncateQueryString')
+    if root.find("RefererBlacklist/Referer") is not None:
+        result.black_referers = _find_all_tags(root, 'RefererBlacklist/Referer')
+
     return result
 
 def parse_condition_include_header(include_header_node):
@@ -669,6 +730,12 @@ def parse_lifecycle_storage_transitions(storage_transition_nodes):
         elif storage_transition_node.find('CreatedBeforeDate') is not None:
             storage_transition.created_before_date = iso8601_to_date(_find_tag(storage_transition_node,
                                                                                'CreatedBeforeDate'))
+        if storage_transition_node.find('IsAccessTime') is not None:
+            storage_transition.is_access_time = _find_bool(storage_transition_node, 'IsAccessTime')
+        if storage_transition_node.find('ReturnToStdWhenVisit') is not None:
+            storage_transition.return_to_std_when_visit = _find_bool(storage_transition_node, 'ReturnToStdWhenVisit')
+        if storage_transition_node.find('AllowSmallFile') is not None:
+            storage_transition.allow_small_file = _find_bool(storage_transition_node, 'AllowSmallFile')
 
         storage_transitions.append(storage_transition)
 
@@ -703,6 +770,13 @@ def parse_lifecycle_verison_storage_transitions(version_storage_transition_nodes
         storage_class = _find_tag(transition_node, 'StorageClass')
         non_crurrent_days = _find_int(transition_node, 'NoncurrentDays')
         version_storage_transition = NoncurrentVersionStorageTransition(non_crurrent_days, storage_class)
+        if transition_node.find('IsAccessTime') is not None:
+            version_storage_transition.is_access_time = _find_bool(transition_node, 'IsAccessTime')
+        if transition_node.find('ReturnToStdWhenVisit') is not None:
+            version_storage_transition.return_to_std_when_visit = _find_bool(transition_node, 'ReturnToStdWhenVisit')
+        if transition_node.find('AllowSmallFile') is not None:
+            version_storage_transition.allow_small_file = _find_bool(transition_node, 'AllowSmallFile')
+
         version_storage_transitions.append(version_storage_transition)
 
     return version_storage_transitions
@@ -719,6 +793,7 @@ def parse_get_bucket_lifecycle(result, body):
         tagging = parse_lifecycle_object_taggings(rule_node.findall('Tag'))
         noncurrent_version_expiration = parse_lifecycle_version_expiration(rule_node.find('NoncurrentVersionExpiration'))
         noncurrent_version_sotrage_transitions = parse_lifecycle_verison_storage_transitions(rule_node.findall('NoncurrentVersionTransition'))
+        lifecycle_filter = parse_lifecycle_filter(rule_node.find('Filter'))
 
         rule = LifecycleRule(
             _find_tag(rule_node, 'ID'),
@@ -729,7 +804,9 @@ def parse_get_bucket_lifecycle(result, body):
             storage_transitions=storage_transitions,
             tagging=tagging,
             noncurrent_version_expiration = noncurrent_version_expiration,
-            noncurrent_version_sotrage_transitions = noncurrent_version_sotrage_transitions
+            noncurrent_version_sotrage_transitions = noncurrent_version_sotrage_transitions,
+            atime_base=int(_find_tag_with_default(rule_node, 'AtimeBase', 0)),
+            filter=lifecycle_filter
             )
         result.rules.append(rule)
 
@@ -824,6 +901,15 @@ def to_put_bucket_referer(bucket_referer):
     for r in bucket_referer.referers:
         _add_text_child(list_node, 'Referer', r)
 
+    if bucket_referer.allow_truncate_query_string is not None:
+        _add_text_child(root, 'AllowTruncateQueryString', str(bucket_referer.allow_truncate_query_string).lower())
+
+    if bucket_referer.black_referers:
+        black_referer_node = ElementTree.SubElement(root, 'RefererBlacklist')
+
+        for r in bucket_referer.black_referers:
+            _add_text_child(black_referer_node, 'Referer', r)
+
     return _node_to_string(root)
 
 
@@ -952,6 +1038,12 @@ def to_put_bucket_lifecycle(bucket_lifecycle):
             for storage_transition in storage_transitions:
                 storage_transition_node = ElementTree.SubElement(rule_node, 'Transition')
                 _add_text_child(storage_transition_node, 'StorageClass', str(storage_transition.storage_class))
+                if storage_transition.is_access_time is not None:
+                    _add_text_child(storage_transition_node, 'IsAccessTime', str(storage_transition.is_access_time).lower())
+                if storage_transition.return_to_std_when_visit is not None:
+                    _add_text_child(storage_transition_node, 'ReturnToStdWhenVisit', str(storage_transition.return_to_std_when_visit).lower())
+                if storage_transition.allow_small_file is not None:
+                    _add_text_child(storage_transition_node, 'AllowSmallFile', str(storage_transition.allow_small_file).lower())
                 if storage_transition.days is not None:
                     _add_text_child(storage_transition_node, 'Days', str(storage_transition.days))
                 elif storage_transition.created_before_date is not None:
@@ -977,6 +1069,28 @@ def to_put_bucket_lifecycle(bucket_lifecycle):
                 version_transition_node = ElementTree.SubElement(rule_node, 'NoncurrentVersionTransition')
                 _add_text_child(version_transition_node, 'NoncurrentDays', str(noncurrent_version_sotrage_transition.noncurrent_days))
                 _add_text_child(version_transition_node, 'StorageClass', str(noncurrent_version_sotrage_transition.storage_class))
+                if noncurrent_version_sotrage_transition.is_access_time is not None:
+                    _add_text_child(version_transition_node, 'IsAccessTime', str(noncurrent_version_sotrage_transition.is_access_time).lower())
+                if noncurrent_version_sotrage_transition.return_to_std_when_visit is not None:
+                    _add_text_child(version_transition_node, 'ReturnToStdWhenVisit', str(noncurrent_version_sotrage_transition.return_to_std_when_visit).lower())
+                if noncurrent_version_sotrage_transition.allow_small_file is not None:
+                    _add_text_child(version_transition_node, 'AllowSmallFile', str(noncurrent_version_sotrage_transition.allow_small_file).lower())
+
+        if rule.filter:
+            filter_node = ElementTree.SubElement(rule_node, "Filter")
+            if rule.filter.object_size_greater_than:
+                _add_text_child(filter_node, 'ObjectSizeGreaterThan', str(rule.filter.object_size_greater_than))
+            if rule.filter.object_size_less_than:
+                _add_text_child(filter_node, 'ObjectSizeLessThan', str(rule.filter.object_size_less_than))
+            if rule.filter.filter_not:
+                for not_arg in rule.filter.filter_not:
+                    not_node = ElementTree.SubElement(filter_node, 'Not')
+
+                    _add_text_child(not_node, 'Prefix', not_arg.prefix)
+                    if not_arg.tag:
+                        tag_node = ElementTree.SubElement(not_node, 'Tag')
+                        _add_text_child(tag_node, 'Key', not_arg.tag.key)
+                        _add_text_child(tag_node, 'Value', not_arg.tag.value)
 
     return _node_to_string(root)
 
@@ -1252,6 +1366,7 @@ def parse_list_object_versions(result, body):
         versionInfo.storage_class = _find_tag(version, "StorageClass")
         versionInfo.size = _find_int(version, "Size")
         versionInfo.etag = _find_tag(version, "ETag").strip('"')
+        versionInfo.restore_info = _find_tag_with_default(version, 'RestoreInfo', None)
 
         result.versions.append(versionInfo)
 
@@ -1367,6 +1482,8 @@ def to_put_async_fetch_task(task_config):
         _add_text_child(root, 'Callback', task_config.callback)
     if task_config.ignore_same_key is not None:
         _add_text_child(root, 'IgnoreSameKey', str(task_config.ignore_same_key).lower())
+    if task_config.callback_when_failed is not None:
+        _add_text_child(root, 'CallbackWhenFailed', str(task_config.callback_when_failed).lower())
 
     return _node_to_string(root)
 
@@ -1406,11 +1523,22 @@ def to_put_inventory_configuration(inventory_config):
 
     if inventory_config.included_object_versions is not None:
         _add_text_child(root, "IncludedObjectVersions", inventory_config.included_object_versions)
-    
-    if inventory_config.inventory_filter is not None and inventory_config.inventory_filter.prefix is not None:
+
+    if inventory_config.inventory_filter is not None:
         filter_node = ElementTree.SubElement(root, 'Filter')
-        _add_text_child(filter_node, "Prefix", inventory_config.inventory_filter.prefix)
-    
+        if inventory_config.inventory_filter.prefix is not None:
+            _add_text_child(filter_node, "Prefix", inventory_config.inventory_filter.prefix)
+        if inventory_config.inventory_filter.last_modify_begin_time_stamp is not None:
+            _add_text_child(filter_node, "LastModifyBeginTimeStamp", str(inventory_config.inventory_filter.last_modify_begin_time_stamp))
+        if inventory_config.inventory_filter.last_modify_end_time_stamp is not None:
+            _add_text_child(filter_node, "LastModifyEndTimeStamp", str(inventory_config.inventory_filter.last_modify_end_time_stamp))
+        if inventory_config.inventory_filter.lower_size_bound is not None:
+            _add_text_child(filter_node, "LowerSizeBound", str(inventory_config.inventory_filter.lower_size_bound))
+        if inventory_config.inventory_filter.upper_size_bound is not None:
+            _add_text_child(filter_node, "UpperSizeBound", str(inventory_config.inventory_filter.upper_size_bound))
+        if inventory_config.inventory_filter.storage_class is not None:
+            _add_text_child(filter_node, "StorageClass", inventory_config.inventory_filter.storage_class)
+
     if inventory_config.inventory_schedule is not None and inventory_config.inventory_schedule.frequency is not None:
         schedule_node = ElementTree.SubElement(root, 'Schedule')
         _add_text_child(schedule_node, "Frequency", inventory_config.inventory_schedule.frequency)
@@ -1458,9 +1586,29 @@ def get_Inventory_configuration_from_element(elem):
     result.is_enabled = _find_bool(root, 'IsEnabled')
     result.included_object_versions = _find_tag(root, 'IncludedObjectVersions')
 
-    if root.find("Filter/Prefix") is not None:
-        result.inventory_filter = InventoryFilter(_find_tag(root, 'Filter/Prefix'))
-    
+    if root.find("Filter") is not None:
+        prefix = None
+        last_modify_begin_time_stamp = None
+        last_modify_end_time_stamp = None
+        lower_size_bound = None
+        upper_size_bound = None
+        storage_class = None
+        if root.find("Filter/Prefix") is not None:
+            prefix = _find_tag(root, 'Filter/Prefix')
+        if root.find("Filter/LastModifyBeginTimeStamp") is not None:
+            last_modify_begin_time_stamp = _find_tag_with_default(root, 'Filter/LastModifyBeginTimeStamp', None)
+        if root.find("Filter/LastModifyEndTimeStamp") is not None:
+            last_modify_end_time_stamp = _find_tag_with_default(root, 'Filter/LastModifyEndTimeStamp', None)
+        if root.find("Filter/LowerSizeBound") is not None:
+            lower_size_bound = _find_tag_with_default(root, 'Filter/LowerSizeBound', None)
+        if root.find("Filter/UpperSizeBound") is not None:
+            upper_size_bound = _find_tag_with_default(root, 'Filter/UpperSizeBound', None)
+        if root.find("Filter/StorageClass") is not None:
+            storage_class = _find_tag_with_default(root, 'Filter/StorageClass', None)
+        result.inventory_filter = InventoryFilter(prefix=prefix, last_modify_begin_time_stamp=last_modify_begin_time_stamp,
+                                                  last_modify_end_time_stamp=last_modify_end_time_stamp, lower_size_bound=lower_size_bound,
+                                                  upper_size_bound=upper_size_bound, storage_class=storage_class)
+
     if root.find("Schedule/Frequency") is not None:
         result.inventory_schedule = InventorySchedule(_find_tag(root, 'Schedule/Frequency'))
 
@@ -1694,3 +1842,257 @@ def parse_get_bucket_replication_progress_result(result, body):
 
     result.progress = progress
 
+
+def to_put_bucket_transfer_acceleration(enabled):
+    root = ElementTree.Element('TransferAccelerationConfiguration')
+    _add_text_child(root, 'Enabled', str(enabled))
+    return _node_to_string(root)
+
+
+def parse_get_bucket_transfer_acceleration_result(result, body):
+    root = ElementTree.fromstring(body)
+    result.enabled = _find_tag(root, "Enabled")
+
+
+def to_bucket_cname_configuration(domain, cert=None):
+    root = ElementTree.Element("BucketCnameConfiguration")
+    cname = ElementTree.SubElement(root, 'Cname')
+    _add_text_child(cname, 'Domain', domain)
+    if cert is not None:
+        certificate = ElementTree.SubElement(cname, 'CertificateConfiguration')
+        if cert.cert_id is not None:
+            _add_text_child(certificate, 'CertId', cert.cert_id)
+        if cert.certificate is not None:
+            _add_text_child(certificate, 'Certificate', cert.certificate)
+        if cert.private_key is not None:
+            _add_text_child(certificate, 'PrivateKey',cert.private_key)
+        if cert.previous_cert_id is not None:
+            _add_text_child(certificate, 'PreviousCertId', cert.previous_cert_id)
+        if cert.force is not None:
+            _add_text_child(certificate, 'Force', str(cert.force))
+        if cert.delete_certificate is not None:
+            _add_text_child(certificate, 'DeleteCertificate', str(cert.delete_certificate))
+    return _node_to_string(root)
+
+
+def parse_create_bucket_cname_token(result, body):
+    root = ElementTree.fromstring(body)
+    result.bucket = _find_tag(root, "Bucket")
+    result.cname = _find_tag(root, "Cname")
+    result.token = _find_tag(root, "Token")
+    result.expire_time = _find_tag(root, "ExpireTime")
+
+
+def parse_get_bucket_cname_token(result, body):
+    root = ElementTree.fromstring(body)
+    result.bucket = _find_tag(root, "Bucket")
+    result.cname = _find_tag(root, "Cname")
+    result.token = _find_tag(root, "Token")
+    result.expire_time = _find_tag(root, "ExpireTime")
+
+
+def parse_list_bucket_cname(result, body):
+    root = ElementTree.fromstring(body)
+    result.bucket = _find_tag(root, "Bucket")
+    result.owner = _find_tag(root, "Owner")
+    for cname in root.findall('Cname'):
+        tmp = CnameInfo()
+        tmp.domain = _find_tag_with_default(cname, 'Domain', None)
+        tmp.last_modified = _find_tag_with_default(cname, 'LastModified', None)
+        tmp.status = _find_tag_with_default(cname, 'Status', None)
+        tmp.is_purge_cdn_cache = _find_tag_with_default(cname, 'IsPurgeCdnCache', None)
+
+        cert = cname.find('Certificate')
+        if cert is not None:
+            certificate = CertificateInfo()
+            certificate.type = _find_tag_with_default(cert, 'Type', None)
+            certificate.cert_id = _find_tag_with_default(cert, 'CertId', None)
+            certificate.status = _find_tag_with_default(cert, 'Status', None)
+            certificate.creation_date = _find_tag_with_default(cert, 'CreationDate', None)
+            certificate.fingerprint = _find_tag_with_default(cert, 'Fingerprint', None)
+            certificate.valid_start_date = _find_tag_with_default(cert, 'ValidStartDate', None)
+            certificate.valid_end_date = _find_tag_with_default(cert, 'ValidEndDate', None)
+            tmp.certificate = certificate
+        result.cname.append(tmp)
+
+
+
+def to_do_bucket_meta_query_request(meta_query):
+    root = ElementTree.Element("MetaQuery")
+    if meta_query.next_token is not None:
+        _add_text_child(root, "NextToken", meta_query.next_token)
+    _add_text_child(root, "MaxResults", meta_query.max_results)
+    _add_text_child(root, "Query", meta_query.query)
+    if meta_query.sort is not None:
+        _add_text_child(root, "Sort", meta_query.sort)
+    if meta_query.order is not None:
+        _add_text_child(root, "Order", meta_query.order)
+    if meta_query.aggregations:
+        aggregations_node = ElementTree.SubElement(root, "Aggregations")
+        for aggregation in meta_query.aggregations:
+            aggregation_node = ElementTree.SubElement(aggregations_node, 'Aggregation')
+            if aggregation.field is not None:
+                _add_text_child(aggregation_node, 'Field', aggregation.field)
+            if aggregation.operation is not None:
+                _add_text_child(aggregation_node, 'Operation', aggregation.operation)
+
+    return _node_to_string(root)
+
+
+def parse_get_bucket_meta_query_result(result, body):
+    root = ElementTree.fromstring(body)
+    result.state = _find_tag(root, "State")
+    result.phase = _find_tag(root, "Phase")
+    result.create_time = _find_tag(root, "CreateTime")
+    result.update_time = _find_tag(root, "UpdateTime")
+
+
+def parse_do_bucket_meta_query_result(result, body):
+    root = ElementTree.fromstring(body)
+    result.next_token = _find_tag(root, "NextToken")
+
+    for file in root.findall('Files/File'):
+        tmp = MetaQueryFile()
+        tmp.file_name = _find_tag(file, 'Filename')
+        tmp.size = int(_find_tag_with_default(file, 'Size', 0))
+        tmp.file_modified_time = _find_tag_with_default(file, 'FileModifiedTime', None)
+        tmp.file_create_time = _find_tag_with_default(file, 'FileCreateTime', None)
+        tmp.file_access_time = _find_tag_with_default(file, 'FileAccessTime', None)
+        tmp.oss_object_type = _find_tag_with_default(file, 'OSSObjectType', None)
+        tmp.oss_storage_class = _find_tag_with_default(file, 'OSSStorageClass', None)
+        tmp.object_acl = _find_tag_with_default(file, 'ObjectACL', None)
+        tmp.etag = _find_tag_with_default(file, 'ETag', None)
+        tmp.oss_crc64 = _find_tag_with_default(file, 'OSSCRC64', None)
+        tmp.oss_tagging_count = int(_find_tag_with_default(file, 'OSSTaggingCount', 0))
+        if file.find('OSSTagging') is not None:
+            for tagging in file.find('OSSTagging').findall('Tagging'):
+                tmp_tagging = OSSTaggingInfo(_find_tag(tagging, 'Key'), _find_tag(tagging, 'Value'))
+                tmp.oss_tagging.append(tmp_tagging)
+        if file.find('OSSUserMeta') is not None:
+            for meta in file.find('OSSUserMeta').findall('UserMeta'):
+                tmp_meta = OSSUserMetaInfo(_find_tag(meta, 'Key'), _find_tag(meta, 'Value'))
+                tmp.oss_user_meta.append(tmp_meta)
+        result.files.append(tmp)
+
+    for aggregation in root.findall('Aggregations/Aggregation'):
+        tmp = AggregationsInfo()
+        tmp.field = _find_tag(aggregation, 'Field')
+        tmp.operation = _find_tag(aggregation, 'Operation')
+        tmp.value = float(_find_tag_with_default(aggregation, 'Value', 0))
+
+        for group in aggregation.findall('Groups/Group'):
+            tmp_groups = AggregationGroupInfo(_find_tag(group, 'Value'), int(_find_tag_with_default(group, 'Count', 0)))
+            tmp.groups.append(tmp_groups)
+        result.aggregations.append(tmp)
+
+def parse_dummy_result(result, body):
+    return result
+
+def to_put_bucket_access_monitor(status):
+    root = ElementTree.Element('AccessMonitorConfiguration')
+    _add_text_child(root, 'Status', status)
+    return _node_to_string(root)
+
+def parse_get_bucket_access_monitor_result(result, body):
+    root = ElementTree.fromstring(body)
+
+    access_monitor = AccessMonitorInfo(_find_tag(root, "Status"))
+    result.access_monitor = access_monitor
+
+def parse_lifecycle_filter(filter_node):
+    lifecycle_filter = LifecycleFilter()
+    if filter_node is not None:
+        if filter_node.find('ObjectSizeGreaterThan') is not None:
+            lifecycle_filter.object_size_greater_than = int(_find_tag_with_default(filter_node, 'ObjectSizeGreaterThan', 0))
+        if filter_node.find('ObjectSizeLessThan') is not None:
+            lifecycle_filter.object_size_less_than = int(_find_tag_with_default(filter_node, 'ObjectSizeLessThan', 0))
+        not_nodes = filter_node.findall('Not')
+        if not_nodes is not None:
+            for not_node in not_nodes:
+                prefix = _find_tag_with_default(not_node, 'Prefix', None)
+                key = _find_tag_with_default(not_node, 'Tag/Key', None)
+                value = _find_tag_with_default(not_node, 'Tag/Value', None)
+                tag = FilterNotTag(key, value)
+                filter_not = FilterNot(prefix, tag)
+                lifecycle_filter.filter_not.append(filter_not)
+
+    return lifecycle_filter
+
+def to_put_bucket_resource_group(resourceGroupId):
+    root = ElementTree.Element('BucketResourceGroupConfiguration')
+    _add_text_child(root, 'ResourceGroupId', resourceGroupId)
+    return _node_to_string(root)
+
+def parse_get_bucket_resource_group_result(result, body):
+    root = ElementTree.fromstring(body)
+    result.resource_group_id = _find_tag(root, "ResourceGroupId")
+
+def to_put_bucket_style(content):
+    root = ElementTree.Element('Style')
+    _add_text_child(root, 'Content', content)
+    return _node_to_string(root)
+
+def parse_get_bucket_style_result(result, body):
+    root = ElementTree.fromstring(body)
+    result.name = _find_tag(root, "Name")
+    result.content = _find_tag(root, "Content")
+    result.create_time = _find_tag(root, "CreateTime")
+    result.last_modify_time = _find_tag(root, "LastModifyTime")
+
+def parse_list_bucket_style(result, body):
+    root = ElementTree.fromstring(body)
+    for style in root.findall('Style'):
+        tmp = BucketStyleInfo()
+        tmp.name = _find_tag_with_default(style, 'Name', None)
+        tmp.content = _find_tag_with_default(style, 'Content', None)
+        tmp.create_time = _find_tag_with_default(style, 'CreateTime', None)
+        tmp.last_modify_time = _find_tag_with_default(style, 'LastModifyTime', None)
+
+        result.styles.append(tmp)
+
+
+def parse_describe_regions(result, body):
+    root = ElementTree.fromstring(body)
+    for region in root.findall('RegionInfo'):
+        tmp = RegionInfo()
+        tmp.region = _find_tag_with_default(region, 'Region', None)
+        tmp.internet_endpoint = _find_tag_with_default(region, 'InternetEndpoint', None)
+        tmp.internal_endpoint = _find_tag_with_default(region, 'InternalEndpoint', None)
+        tmp.accelerate_endpoint = _find_tag_with_default(region, 'AccelerateEndpoint', None)
+
+        result.regions.append(tmp)
+
+def parse_async_process_object(result, body):
+    if body:
+        body_dict = eval(body.decode('utf-8'))
+        result.event_id = body_dict['EventId']
+        result.async_request_id = body_dict['RequestId']
+        result.task_id = body_dict['TaskId']
+    return result
+
+def to_do_bucket_callback_policy_request(callback_policy):
+    root = ElementTree.Element("BucketCallbackPolicy")
+    if callback_policy:
+        for policy in callback_policy:
+            if policy:
+                policy_node = ElementTree.SubElement(root, 'PolicyItem')
+                if policy.policy_name is not None:
+                    _add_text_child(policy_node, 'PolicyName', policy.policy_name)
+                if policy.callback is not None:
+                    _add_text_child(policy_node, 'Callback', policy.callback)
+                if policy.callback_var is None:
+                    _add_text_child(policy_node, 'CallbackVar', '')
+                else:
+                    _add_text_child(policy_node, 'CallbackVar', policy.callback_var)
+
+    return _node_to_string(root)
+
+def parse_callback_policy_result(result, body):
+    root = ElementTree.fromstring(body)
+    for policy in root.findall('PolicyItem'):
+        tmp = CallbackPolicyInfo()
+        tmp.policy_name = _find_tag_with_default(policy, 'PolicyName', None)
+        tmp.callback = _find_tag_with_default(policy, 'Callback', None)
+        tmp.callback_var = _find_tag_with_default(policy, 'CallbackVar', None)
+
+        result.callback_policies.append(tmp)
