@@ -3,7 +3,7 @@
 
 import datetime
 import json
-
+from oss2.headers import *
 from .common import *
 from oss2 import to_string
 
@@ -76,13 +76,14 @@ class TestBucket(OssTestCase):
         bucket.delete_bucket()
 
         # ZRS
-        bucketConfig = oss2.models.BucketCreateConfig(oss2.BUCKET_STORAGE_CLASS_IA, oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS)
-        bucket.create_bucket(oss2.BUCKET_ACL_PRIVATE, bucketConfig)
-        wait_meta_sync()
-        
-        result = bucket.get_bucket_info()
-        self.assertEqual(oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS, result.data_redundancy_type)
-        bucket.delete_bucket()
+        if OSS_ENDPOINT.find("oss-cn") != -1:
+            bucketConfig = oss2.models.BucketCreateConfig(oss2.BUCKET_STORAGE_CLASS_IA, oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS)
+            bucket.create_bucket(oss2.BUCKET_ACL_PRIVATE, bucketConfig)
+            wait_meta_sync()
+            
+            result = bucket.get_bucket_info()
+            self.assertEqual(oss2.BUCKET_DATA_REDUNDANCY_TYPE_ZRS, result.data_redundancy_type)
+            bucket.delete_bucket()
 
     def test_acl(self):
         auth = oss2.Auth(OSS_ID, OSS_SECRET)
@@ -171,6 +172,44 @@ class TestBucket(OssTestCase):
 
         self.assertRaises(oss2.exceptions.NoSuchLifecycle, self.bucket.get_bucket_lifecycle)
 
+    def test_lifecycle_overlap(self):
+        from oss2.models import LifecycleExpiration, LifecycleRule, BucketLifecycle
+
+        rule = LifecycleRule(random_string(10), '中文前缀/',
+                             status=LifecycleRule.ENABLED,
+                             expiration=LifecycleExpiration(date=datetime.date(2016, 12, 25)))
+        lifecycle = BucketLifecycle([rule])
+
+        rule2 = LifecycleRule(random_string(10), '中文前缀/2',
+                              status=LifecycleRule.ENABLED,
+                              expiration=LifecycleExpiration(date=datetime.date(2016, 12, 25)))
+        lifecycle.rules.append(rule2)
+
+        headers = dict()
+        headers[OSS_ALLOW_ACTION_OVERLAP] = 'true'
+        self.bucket.put_bucket_lifecycle(lifecycle, headers)
+        self.retry_assert(lambda: self.same_lifecycle(rule, self.bucket))
+
+        self.bucket.delete_bucket_lifecycle()
+
+    def test_lifecycle_overlap_exception(self):
+        from oss2.models import LifecycleExpiration, LifecycleRule, BucketLifecycle
+
+        rule = LifecycleRule(random_string(10), '前缀/',
+                             status=LifecycleRule.ENABLED,
+                             expiration=LifecycleExpiration(date=datetime.date(2016, 12, 25)))
+        lifecycle = BucketLifecycle([rule])
+
+        rule2 = LifecycleRule(random_string(10), '前缀/2',
+                              status=LifecycleRule.ENABLED,
+                              expiration=LifecycleExpiration(date=datetime.date(2016, 12, 25)))
+        lifecycle.rules.append(rule2)
+        try:
+            self.bucket.put_bucket_lifecycle(lifecycle)
+        except oss2.exceptions.OssError as e:
+            self.assertEqual(e.message, 'Overlap for same action type Expiration')
+        self.bucket.delete_bucket_lifecycle()
+
     def test_put_lifecycle_days_less_than_transition_days(self):
         from oss2.models import LifecycleExpiration, LifecycleRule, BucketLifecycle
 
@@ -1249,5 +1288,34 @@ class TestBucket(OssTestCase):
         self.assertEqual(200, result.status)
         self.assertTrue(result.buckets.__len__() > 0)
 
+    def test_bucket_path_style(self):
+        auth = oss2.Auth(OSS_ID, OSS_SECRET)
+        bucket = oss2.Bucket(auth, OSS_ENDPOINT, self.OSS_BUCKET)
+        bucket2 = oss2.Bucket(auth, OSS_ENDPOINT, self.OSS_BUCKET, is_path_style=True)
+
+        service = oss2.Service(auth, OSS_ENDPOINT)
+        service2 = oss2.Service(auth, OSS_ENDPOINT, is_path_style=True)
+
+        try:
+            result = bucket.get_bucket_acl()
+            self.assertEqual(200, result.status)
+            self.assertEqual('private', result.acl)
+
+            bucket2.get_bucket_acl()
+        except oss2.exceptions.OssError as e:
+            self.assertEqual(e.code, 'SecondLevelDomainForbidden')
+
+        try:
+            params = {}
+            params['regionList']=''
+            result = service.list_buckets(params=params)
+            self.assertEqual(200, result.status)
+            self.assertTrue(result.buckets.__len__() > 0)
+
+            service2.list_buckets(params=params)
+        except oss2.exceptions.OssError as e:
+            self.assertEqual(e.code, 'SecondLevelDomainForbidden')
+
+
 if __name__ == '__main__':
     unittest.main()
