@@ -1518,26 +1518,37 @@ class TestObject(OssTestCase):
         self.assertEqual(del_result.status, 204)
         bucket.delete_bucket()
 
-class TestSign(TestObject):
+class TestSignV2(TestObject):
     """
         这个类主要是用来增加测试覆盖率，当环境变量为oss2.AUTH_VERSION_2，则重新设置为oss2.AUTH_VERSION_1再运行TestObject，反之亦然
     """
     def __init__(self, *args, **kwargs):
-        super(TestSign, self).__init__(*args, **kwargs)
+        self.sign_vesion = os.getenv('OSS_TEST_AUTH_VERSION')
+        super(TestSignV2, self).__init__(*args, **kwargs)
 
     def setUp(self):
-        if os.getenv('OSS_TEST_AUTH_VERSION') == oss2.AUTH_VERSION_2:
-            os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_1
-        else:
-            os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_2
-        super(TestSign, self).setUp()
+        os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_2
+        super(TestSignV2, self).setUp()
 
     def tearDown(self):
-        if os.getenv('OSS_TEST_AUTH_VERSION') == oss2.AUTH_VERSION_2:
-            os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_1
-        else:
-            os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_2
-        super(TestSign, self).tearDown()
+        os.environ['OSS_TEST_AUTH_VERSION'] = self.sign_vesion
+        super(TestSignV2, self).tearDown()
+
+class TestSignV4(TestObject):
+    """
+        这个类主要是用来增加测试覆盖率，当环境变量为oss2.AUTH_VERSION_2，则重新设置为oss2.AUTH_VERSION_1再运行TestObject，反之亦然
+    """
+    def __init__(self, *args, **kwargs):
+        self.sign_vesion = os.getenv('OSS_TEST_AUTH_VERSION')
+        super(TestSignV4, self).__init__(*args, **kwargs)
+
+    def setUp(self):
+        os.environ['OSS_TEST_AUTH_VERSION'] = oss2.AUTH_VERSION_4
+        super(TestSignV4, self).setUp()
+
+    def tearDown(self):
+        os.environ['OSS_TEST_AUTH_VERSION'] = self.sign_vesion
+        super(TestSignV4, self).tearDown()
 
 
 if __name__ == '__main__':
